Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(308)

Unified Diff: net/http/http_stream_parser.h

Issue 9284033: net: Give more descriptive names for code around the request merging logic. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 8 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: net/http/http_stream_parser.h
diff --git a/net/http/http_stream_parser.h b/net/http/http_stream_parser.h
index b87beab733300dc51af56238cc2a845d17353b6f..303bc108f3a6319607e7176aefd25c692a9870f7 100644
--- a/net/http/http_stream_parser.h
+++ b/net/http/http_stream_parser.h
@@ -91,10 +91,11 @@ class NET_EXPORT_PRIVATE HttpStreamParser : public ChunkCallback {
char* output,
size_t output_size);
- // Returns true if request and body should be merged (i.e. the sum is
- // small enough and the body is in memory, and not chunked).
- static bool ShouldMerge(const std::string& request,
- const UploadDataStream* request_body);
+ // Returns true if request headers and body should be merged (i.e. the
+ // sum is small enough and the body is in memory, and not chunked).
+ static bool ShouldMergeRequestHeadersAndBody(
+ const std::string& request_headers,
+ const UploadDataStream* request_body);
// The number of extra bytes required to encode a chunk.
static const size_t kChunkHeaderFooterSize;

Powered by Google App Engine
This is Rietveld 408576698